@@ -4,13 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
-
-> The APIs of higher level constructs in this module are experimental and under active development.
-> They are subject to non-backward compatible changes or removal in any future version. These are
-> not subject to the [Semantic Versioning](https://semver.org/) model and breaking changes will be
-> announced in the release notes. This means that while you may use them, you may need to update
-> your source code when upgrading to a newer version of this package.
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -53,17 +47,12 @@ class AddHeader(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-ses-actions.AddHeader",
 ):
-    '''(experimental) Adds a header to the received email.
-
-    :stability: experimental
-    '''
+    '''Adds a header to the received email.'''
 
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
         '''
-        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
-
-        :stability: experimental
+        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
         '''
         props = AddHeaderProps(name=name, value=value)
 
@@ -74,11 +63,9 @@ class AddHeader(
         self,
         _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param _rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
@@ -90,12 +77,10 @@ class AddHeader(
 )
 class AddHeaderProps:
     def __init__(self, *, name: builtins.str, value: builtins.str) -> None:
-        '''(experimental) Construction properties for a add header action.
+        '''Construction properties for a add header action.
 
-        :param name: (experimental) The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
-        :param value: (experimental) The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
-
-        :stability: experimental
+        :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
+        :param value: The value of the header to add. Must be less than 2048 characters, and must not contain newline characters ("\\r" or "\\n").
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -104,13 +89,11 @@ class AddHeaderProps:
 
     @builtins.property
     def name(self) -> builtins.str:
-        '''(experimental) The name of the header to add.
+        '''The name of the header to add.
 
         Must be between 1 and 50 characters,
         inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters
         and dashes only.
-
-        :stability: experimental
         '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
@@ -118,12 +101,10 @@ class AddHeaderProps:
 
     @builtins.property
     def value(self) -> builtins.str:
-        '''(experimental) The value of the header to add.
+        '''The value of the header to add.
 
         Must be less than 2048 characters,
         and must not contain newline characters ("\\r" or "\\n").
-
-        :stability: experimental
         '''
         result = self._values.get("value")
         assert result is not None, "Required property 'value' is missing"
@@ -143,10 +124,7 @@ class AddHeaderProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce"):
-    '''(experimental) Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
-
-    :stability: experimental
-    '''
+    '''Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.'''
 
     def __init__(
         self,
@@ -156,11 +134,9 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         '''
-        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: (experimental) The template containing the message, reply code and status code.
-        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
-
-        :stability: experimental
+        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: The template containing the message, reply code and status code.
+        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
         '''
         props = BounceProps(sender=sender, template=template, topic=topic)
 
@@ -171,11 +147,9 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Bounce
         self,
         _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param _rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
@@ -193,13 +167,11 @@ class BounceProps:
         template: "BounceTemplate",
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        '''(experimental) Construction properties for a bounce action.
+        '''Construction properties for a bounce action.
 
-        :param sender: (experimental) The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
-        :param template: (experimental) The template containing the message, reply code and status code.
-        :param topic: (experimental) The SNS topic to notify when the bounce action is taken. Default: no notification
-
-        :stability: experimental
+        :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
+        :param template: The template containing the message, reply code and status code.
+        :param topic: The SNS topic to notify when the bounce action is taken. Default: no notification
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "sender": sender,
@@ -210,12 +182,10 @@ class BounceProps:
 
     @builtins.property
     def sender(self) -> builtins.str:
-        '''(experimental) The email address of the sender of the bounced email.
+        '''The email address of the sender of the bounced email.
 
         This is the address
         from which the bounce message will be sent.
-
-        :stability: experimental
         '''
         result = self._values.get("sender")
         assert result is not None, "Required property 'sender' is missing"
@@ -223,21 +193,16 @@ class BounceProps:
 
     @builtins.property
     def template(self) -> "BounceTemplate":
-        '''(experimental) The template containing the message, reply code and status code.
-
-        :stability: experimental
-        '''
+        '''The template containing the message, reply code and status code.'''
         result = self._values.get("template")
         assert result is not None, "Required property 'template' is missing"
         return typing.cast("BounceTemplate", result)
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        '''(experimental) The SNS topic to notify when the bounce action is taken.
+        '''The SNS topic to notify when the bounce action is taken.
 
         :default: no notification
-
-        :stability: experimental
         '''
         result = self._values.get("topic")
         return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
@@ -258,10 +223,7 @@ class BounceTemplate(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-ses-actions.BounceTemplate",
 ):
-    '''(experimental) A bounce template.
-
-    :stability: experimental
-    '''
+    '''A bounce template.'''
 
     def __init__(
         self,
@@ -271,11 +233,9 @@ class BounceTemplate(
         status_code: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param message: (experimental) Human-readable text to include in the bounce message.
-        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
-        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
-
-        :stability: experimental
+        :param message: Human-readable text to include in the bounce message.
+        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
+        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
         '''
         props = BounceTemplateProps(
             message=message, smtp_reply_code=smtp_reply_code, status_code=status_code
@@ -286,49 +246,31 @@ class BounceTemplate(
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MAILBOX_DOES_NOT_EXIST")
     def MAILBOX_DOES_NOT_EXIST(cls) -> "BounceTemplate":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplate", jsii.sget(cls, "MAILBOX_DOES_NOT_EXIST"))
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MAILBOX_FULL")
     def MAILBOX_FULL(cls) -> "BounceTemplate":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplate", jsii.sget(cls, "MAILBOX_FULL"))
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MESSAGE_CONTENT_REJECTED")
     def MESSAGE_CONTENT_REJECTED(cls) -> "BounceTemplate":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplate", jsii.sget(cls, "MESSAGE_CONTENT_REJECTED"))
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="MESSAGE_TOO_LARGE")
     def MESSAGE_TOO_LARGE(cls) -> "BounceTemplate":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplate", jsii.sget(cls, "MESSAGE_TOO_LARGE"))
 
     @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="TEMPORARY_FAILURE")
     def TEMPORARY_FAILURE(cls) -> "BounceTemplate":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplate", jsii.sget(cls, "TEMPORARY_FAILURE"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="props")
     def props(self) -> "BounceTemplateProps":
-        '''
-        :stability: experimental
-        '''
         return typing.cast("BounceTemplateProps", jsii.get(self, "props"))
 
 
@@ -349,13 +291,11 @@ class BounceTemplateProps:
         smtp_reply_code: builtins.str,
         status_code: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''(experimental) Construction properties for a BounceTemplate.
+        '''Construction properties for a BounceTemplate.
 
-        :param message: (experimental) Human-readable text to include in the bounce message.
-        :param smtp_reply_code: (experimental) The SMTP reply code, as defined by RFC 5321.
-        :param status_code: (experimental) The SMTP enhanced status code, as defined by RFC 3463.
-
-        :stability: experimental
+        :param message: Human-readable text to include in the bounce message.
+        :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
+        :param status_code: The SMTP enhanced status code, as defined by RFC 3463.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "message": message,
@@ -366,20 +306,16 @@ class BounceTemplateProps:
 
     @builtins.property
     def message(self) -> builtins.str:
-        '''(experimental) Human-readable text to include in the bounce message.
-
-        :stability: experimental
-        '''
+        '''Human-readable text to include in the bounce message.'''
         result = self._values.get("message")
         assert result is not None, "Required property 'message' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def smtp_reply_code(self) -> builtins.str:
-        '''(experimental) The SMTP reply code, as defined by RFC 5321.
+        '''The SMTP reply code, as defined by RFC 5321.
 
         :see: https://tools.ietf.org/html/rfc5321
-        :stability: experimental
         '''
         result = self._values.get("smtp_reply_code")
         assert result is not None, "Required property 'smtp_reply_code' is missing"
@@ -387,10 +323,9 @@ class BounceTemplateProps:
 
     @builtins.property
     def status_code(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The SMTP enhanced status code, as defined by RFC 3463.
+        '''The SMTP enhanced status code, as defined by RFC 3463.
 
         :see: https://tools.ietf.org/html/rfc3463
-        :stability: experimental
         '''
         result = self._values.get("status_code")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -409,29 +344,17 @@ class BounceTemplateProps:
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.EmailEncoding")
 class EmailEncoding(enum.Enum):
-    '''(experimental) The type of email encoding to use for a SNS action.
-
-    :stability: experimental
-    '''
+    '''The type of email encoding to use for a SNS action.'''
 
     BASE64 = "BASE64"
-    '''(experimental) Base 64.
-
-    :stability: experimental
-    '''
+    '''Base 64.'''
     UTF8 = "UTF8"
-    '''(experimental) UTF-8.
-
-    :stability: experimental
-    '''
+    '''UTF-8.'''
 
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda"):
-    '''(experimental) Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
-
-    :stability: experimental
-    '''
+    '''Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.'''
 
     def __init__(
         self,
@@ -441,11 +364,9 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         '''
-        :param function: (experimental) The Lambda function to invoke.
-        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
-        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
-
-        :stability: experimental
+        :param function: The Lambda function to invoke.
+        :param invocation_type: The invocation type of the Lambda function. Default: Event
+        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
         '''
         props = LambdaProps(
             function=function, invocation_type=invocation_type, topic=topic
@@ -458,35 +379,25 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Lambda
         self,
         rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
 @jsii.enum(jsii_type="@aws-cdk/aws-ses-actions.LambdaInvocationType")
 class LambdaInvocationType(enum.Enum):
-    '''(experimental) The type of invocation to use for a Lambda Action.
-
-    :stability: experimental
-    '''
+    '''The type of invocation to use for a Lambda Action.'''
 
     EVENT = "EVENT"
-    '''(experimental) The function will be invoked asynchronously.
-
-    :stability: experimental
-    '''
+    '''The function will be invoked asynchronously.'''
     REQUEST_RESPONSE = "REQUEST_RESPONSE"
-    '''(experimental) The function will be invoked sychronously.
+    '''The function will be invoked sychronously.
 
     Use RequestResponse only when
     you want to make a mail flow decision, such as whether to stop the receipt
     rule or the receipt rule set.
-
-    :stability: experimental
     '''
 
 
@@ -507,13 +418,11 @@ class LambdaProps:
         invocation_type: typing.Optional[LambdaInvocationType] = None,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        '''(experimental) Construction properties for a Lambda action.
+        '''Construction properties for a Lambda action.
 
-        :param function: (experimental) The Lambda function to invoke.
-        :param invocation_type: (experimental) The invocation type of the Lambda function. Default: Event
-        :param topic: (experimental) The SNS topic to notify when the Lambda action is taken. Default: no notification
-
-        :stability: experimental
+        :param function: The Lambda function to invoke.
+        :param invocation_type: The invocation type of the Lambda function. Default: Event
+        :param topic: The SNS topic to notify when the Lambda action is taken. Default: no notification
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "function": function,
@@ -525,32 +434,25 @@ class LambdaProps:
 
     @builtins.property
     def function(self) -> aws_cdk.aws_lambda.IFunction:
-        '''(experimental) The Lambda function to invoke.
-
-        :stability: experimental
-        '''
+        '''The Lambda function to invoke.'''
         result = self._values.get("function")
         assert result is not None, "Required property 'function' is missing"
         return typing.cast(aws_cdk.aws_lambda.IFunction, result)
 
     @builtins.property
     def invocation_type(self) -> typing.Optional[LambdaInvocationType]:
-        '''(experimental) The invocation type of the Lambda function.
+        '''The invocation type of the Lambda function.
 
         :default: Event
-
-        :stability: experimental
         '''
         result = self._values.get("invocation_type")
         return typing.cast(typing.Optional[LambdaInvocationType], result)
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        '''(experimental) The SNS topic to notify when the Lambda action is taken.
+        '''The SNS topic to notify when the Lambda action is taken.
 
         :default: no notification
-
-        :stability: experimental
         '''
         result = self._values.get("topic")
         return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
@@ -569,10 +471,7 @@ class LambdaProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
-    '''(experimental) Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.
-
-    :stability: experimental
-    '''
+    '''Saves the received message to an Amazon S3 bucket and, optionally, publishes a notification to Amazon SNS.'''
 
     def __init__(
         self,
@@ -583,12 +482,10 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         '''
-        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
-        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
-        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
-
-        :stability: experimental
+        :param bucket: The S3 bucket that incoming email will be saved to.
+        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
+        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
         '''
         props = S3Props(
             bucket=bucket,
@@ -604,11 +501,9 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.S3"):
         self,
         rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -632,14 +527,12 @@ class S3Props:
         object_key_prefix: typing.Optional[builtins.str] = None,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        '''(experimental) Construction properties for a S3 action.
+        '''Construction properties for a S3 action.
 
-        :param bucket: (experimental) The S3 bucket that incoming email will be saved to.
-        :param kms_key: (experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
-        :param object_key_prefix: (experimental) The key prefix of the S3 bucket. Default: no prefix
-        :param topic: (experimental) The SNS topic to notify when the S3 action is taken. Default: no notification
-
-        :stability: experimental
+        :param bucket: The S3 bucket that incoming email will be saved to.
+        :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
+        :param object_key_prefix: The key prefix of the S3 bucket. Default: no prefix
+        :param topic: The SNS topic to notify when the S3 action is taken. Default: no notification
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
@@ -653,43 +546,34 @@ class S3Props:
 
     @builtins.property
     def bucket(self) -> aws_cdk.aws_s3.IBucket:
-        '''(experimental) The S3 bucket that incoming email will be saved to.
-
-        :stability: experimental
-        '''
+        '''The S3 bucket that incoming email will be saved to.'''
         result = self._values.get("bucket")
         assert result is not None, "Required property 'bucket' is missing"
         return typing.cast(aws_cdk.aws_s3.IBucket, result)
 
     @builtins.property
     def kms_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
-        '''(experimental) The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
+        '''The master key that SES should use to encrypt your emails before saving them to the S3 bucket.
 
         :default: no encryption
-
-        :stability: experimental
         '''
         result = self._values.get("kms_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
     @builtins.property
     def object_key_prefix(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The key prefix of the S3 bucket.
+        '''The key prefix of the S3 bucket.
 
         :default: no prefix
-
-        :stability: experimental
         '''
         result = self._values.get("object_key_prefix")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        '''(experimental) The SNS topic to notify when the S3 action is taken.
+        '''The SNS topic to notify when the S3 action is taken.
 
         :default: no notification
-
-        :stability: experimental
         '''
         result = self._values.get("topic")
         return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
@@ -708,10 +592,7 @@ class S3Props:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
-    '''(experimental) Publishes the email content within a notification to Amazon SNS.
-
-    :stability: experimental
-    '''
+    '''Publishes the email content within a notification to Amazon SNS.'''
 
     def __init__(
         self,
@@ -720,10 +601,8 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
         '''
-        :param topic: (experimental) The SNS topic to notify.
-        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
-
-        :stability: experimental
+        :param topic: The SNS topic to notify.
+        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
         '''
         props = SnsProps(topic=topic, encoding=encoding)
 
@@ -734,11 +613,9 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Sns"):
         self,
         _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param _rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
@@ -755,12 +632,10 @@ class SnsProps:
         topic: aws_cdk.aws_sns.ITopic,
         encoding: typing.Optional[EmailEncoding] = None,
     ) -> None:
-        '''(experimental) Construction properties for a SNS action.
+        '''Construction properties for a SNS action.
 
-        :param topic: (experimental) The SNS topic to notify.
-        :param encoding: (experimental) The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
-
-        :stability: experimental
+        :param topic: The SNS topic to notify.
+        :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "topic": topic,
@@ -770,21 +645,16 @@ class SnsProps:
 
     @builtins.property
     def topic(self) -> aws_cdk.aws_sns.ITopic:
-        '''(experimental) The SNS topic to notify.
-
-        :stability: experimental
-        '''
+        '''The SNS topic to notify.'''
         result = self._values.get("topic")
         assert result is not None, "Required property 'topic' is missing"
         return typing.cast(aws_cdk.aws_sns.ITopic, result)
 
     @builtins.property
     def encoding(self) -> typing.Optional[EmailEncoding]:
-        '''(experimental) The encoding to use for the email within the Amazon SNS notification.
+        '''The encoding to use for the email within the Amazon SNS notification.
 
         :default: UTF-8
-
-        :stability: experimental
         '''
         result = self._values.get("encoding")
         return typing.cast(typing.Optional[EmailEncoding], result)
@@ -803,10 +673,7 @@ class SnsProps:
 
 @jsii.implements(aws_cdk.aws_ses.IReceiptRuleAction)
 class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
-    '''(experimental) Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
-
-    :stability: experimental
-    '''
+    '''Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.'''
 
     def __init__(
         self,
@@ -814,9 +681,7 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
         '''
-        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
-
-        :stability: experimental
+        :param topic: The SNS topic to notify when the stop action is taken.
         '''
         props = StopProps(topic=topic)
 
@@ -827,11 +692,9 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-ses-actions.Stop"):
         self,
         _rule: aws_cdk.aws_ses.IReceiptRule,
     ) -> aws_cdk.aws_ses.ReceiptRuleActionConfig:
-        '''(experimental) (experimental) Returns the receipt rule action specification.
+        '''Returns the receipt rule action specification.
 
         :param _rule: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ses.ReceiptRuleActionConfig, jsii.invoke(self, "bind", [_rule]))
 
@@ -847,11 +710,9 @@ class StopProps:
         *,
         topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
     ) -> None:
-        '''(experimental) Construction properties for a stop action.
+        '''Construction properties for a stop action.
 
-        :param topic: (experimental) The SNS topic to notify when the stop action is taken.
-
-        :stability: experimental
+        :param topic: The SNS topic to notify when the stop action is taken.
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if topic is not None:
@@ -859,10 +720,7 @@ class StopProps:
 
     @builtins.property
     def topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
-        '''(experimental) The SNS topic to notify when the stop action is taken.
-
-        :stability: experimental
-        '''
+        '''The SNS topic to notify when the stop action is taken.'''
         result = self._values.get("topic")
         return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
 
